[![FactSet](https://raw.githubusercontent.com/factset/enterprise-sdk/main/docs/images/factset-logo.svg)](https://www.factset.com)

# FactSet Prices client library for Python

[![API Version](https://img.shields.io/badge/api-v1.3.0-blue)]()
[![PyPi](https://img.shields.io/pypi/v/fds.sdk.FactSetPrices)](https://pypi.org/project/fds.sdk.FactSetPrices/)
[![Apache-2 license](https://img.shields.io/badge/license-Apache2-brightgreen.svg)](https://www.apache.org/licenses/LICENSE-2.0)

Gain access to comprehensive global coverage for Equities & Fixed Income. Perform quick analytics by controlling the date ranges, currencies, and rolling periods, or simply request Open, High, Low, and Close prices. Easily connect pricing data with other core company data or alternative content sets using FactSet's hub and spoke symbology. <p>Equity and Fund Security types include Common Stock, ADR, GDR, Preferred, Closed-ended Fund, Exchange Traded Fund, Unit, Open-ended Fund, Exchange Traded Fund UVI, Exchange Traded Fund NAV, Preferred Equity, Non-Voting Depositary Receipt/Certificate, Alien/Foreign, Structured Product, and Temporary Instruments. Reference over 180,000+ active and inactive securities.</p><p>Fixed Income Security Types include Corporate Bonds, Treasury and Agency bonds, Government Bonds, and Municipals.</p><p><b>Rate limit is set to 25 requests per second</b>.</p>


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.3.0
- SDK version: 1.1.13
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements

* Python >= 3.7

## Installation

### Poetry

```shell
poetry add fds.sdk.utils fds.sdk.FactSetPrices==1.1.13
```

### pip

```shell
pip install fds.sdk.utils fds.sdk.FactSetPrices==1.1.13
```

## Usage

1. [Generate authentication credentials](../../../../README.md#authentication).
2. Setup Python environment.
   1. Install and activate python 3.7+. If you're using [pyenv](https://github.com/pyenv/pyenv):

      ```sh
      pyenv install 3.9.7
      pyenv shell 3.9.7
      ```

   2. (optional) [Install poetry](https://python-poetry.org/docs/#installation).
3. [Install dependencies](#installation).
4. Run the following:

> [!IMPORTANT]
> The parameter variables defined below are just examples and may potentially contain non valid values. Please replace them with valid values.

### Example Code

```python
from fds.sdk.utils.authentication import ConfidentialClient

import fds.sdk.FactSetPrices
from fds.sdk.FactSetPrices.api import batch_processing_api
from fds.sdk.FactSetPrices.models import *
from dateutil.parser import parse as dateutil_parser
from pprint import pprint

# See configuration.py for a list of all supported configuration parameters.

# Examples for each supported authentication method are below,
# choose one that satisfies your use case.

# (Preferred) OAuth 2.0: FactSetOAuth2
# See https://github.com/FactSet/enterprise-sdk#oauth-20
# for information on how to create the app-config.json file
#
# The confidential client instance should be reused in production environments.
# See https://github.com/FactSet/enterprise-sdk-utils-python#authentication
# for more information on using the ConfidentialClient class
configuration = fds.sdk.FactSetPrices.Configuration(
    fds_oauth_client=ConfidentialClient('/path/to/app-config.json')
)

# Basic authentication: FactSetApiKey
# See https://github.com/FactSet/enterprise-sdk#api-key
# for information how to create an API key
# configuration = fds.sdk.FactSetPrices.Configuration(
#     username='USERNAME-SERIAL',
#     password='API-KEY'
# )

# Enter a context with an instance of the API client
with fds.sdk.FactSetPrices.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = batch_processing_api.BatchProcessingApi(api_client)
    id = "id_example" # str | Batch Request identifier.

    try:
        # Returns the response for a Batch Request
        # example passing only required values which don't have defaults set
        api_response_wrapper = api_instance.get_batch_data(id)

        # This endpoint returns a response wrapper that contains different types of responses depending on the query.
        # To access the correct response type, you need to perform one additional step, as shown below.
        if api_response_wrapper.get_status_code() == 200:
            api_response = api_response_wrapper.get_response_200()
        if api_response_wrapper.get_status_code() == 202:
            api_response = api_response_wrapper.get_response_202()

        pprint(api_response)
    except fds.sdk.FactSetPrices.ApiException as e:
        print("Exception when calling BatchProcessingApi->get_batch_data: %s\n" % e)

    # # Get response, http status code and response headers
    # try:
    #     # Returns the response for a Batch Request
    #     api_response_wrapper, http_status_code, response_headers = api_instance.get_batch_data_with_http_info(id)

    #     # This endpoint returns a response wrapper that contains different types of responses depending on the query.
    #     # To access the correct response type, you need to perform one additional step, as shown below.
    #     if api_response_wrapper.get_status_code() == 200:
    #         api_response = api_response_wrapper.get_response_200()
    #     if api_response_wrapper.get_status_code() == 202:
    #         api_response = api_response_wrapper.get_response_202()

    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.FactSetPrices.ApiException as e:
    #     print("Exception when calling BatchProcessingApi->get_batch_data: %s\n" % e)

    # # Get response asynchronous
    # try:
    #     # Returns the response for a Batch Request
    #     async_result = api_instance.get_batch_data_async(id)
    #     api_response_wrapper = async_result.get()

    #     # This endpoint returns a response wrapper that contains different types of responses depending on the query.
    #     # To access the correct response type, you need to perform one additional step, as shown below.
    #     if api_response_wrapper.get_status_code() == 200:
    #         api_response = api_response_wrapper.get_response_200()
    #     if api_response_wrapper.get_status_code() == 202:
    #         api_response = api_response_wrapper.get_response_202()

    #     pprint(api_response)
    # except fds.sdk.FactSetPrices.ApiException as e:
    #     print("Exception when calling BatchProcessingApi->get_batch_data: %s\n" % e)

    # # Get response, http status code and response headers asynchronous
    # try:
    #     # Returns the response for a Batch Request
    #     async_result = api_instance.get_batch_data_with_http_info_async(id)
    #     api_response_wrapper, http_status_code, response_headers = async_result.get()

    #     # This endpoint returns a response wrapper that contains different types of responses depending on the query.
    #     # To access the correct response type, you need to perform one additional step, as shown below.
    #     if api_response_wrapper.get_status_code() == 200:
    #         api_response = api_response_wrapper.get_response_200()
    #     if api_response_wrapper.get_status_code() == 202:
    #         api_response = api_response_wrapper.get_response_202()

    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.FactSetPrices.ApiException as e:
    #     print("Exception when calling BatchProcessingApi->get_batch_data: %s\n" % e)

```

### Using Pandas

To convert an API response to a Pandas DataFrame, it is necessary to transform it first to a dictionary.
```python
import pandas as pd

response_dict = api_response.to_dict()['data']

simple_json_response = pd.DataFrame(response_dict)
nested_json_response = pd.json_normalize(response_dict)
```

### Debugging

The SDK uses the standard library [`logging`](https://docs.python.org/3/library/logging.html#module-logging) module.

Setting `debug` to `True` on an instance of the `Configuration` class sets the log-level of related packages to `DEBUG`
and enables additional logging in Pythons [HTTP Client](https://docs.python.org/3/library/http.client.html).

**Note**: This prints out sensitive information (e.g. the full request and response). Use with care.

```python
import logging
import fds.sdk.FactSetPrices

logging.basicConfig(level=logging.DEBUG)

configuration = fds.sdk.FactSetPrices.Configuration(...)
configuration.debug = True
```

### Configure a Proxy

You can pass proxy settings to the Configuration class:

* `proxy`: The URL of the proxy to use.
* `proxy_headers`: a dictionary to pass additional headers to the proxy (e.g. `Proxy-Authorization`).

```python
import fds.sdk.FactSetPrices

configuration = fds.sdk.FactSetPrices.Configuration(
    # ...
    proxy="http://secret:password@localhost:5050",
    proxy_headers={
        "Custom-Proxy-Header": "Custom-Proxy-Header-Value"
    }
)
```

### Custom SSL Certificate

TLS/SSL certificate verification can be configured with the following Configuration parameters:

* `ssl_ca_cert`: a path to the certificate to use for verification in `PEM` format.
* `verify_ssl`: setting this to `False` disables the verification of certificates.
  Disabling the verification is not recommended, but it might be useful during
  local development or testing.

```python
import fds.sdk.FactSetPrices

configuration = fds.sdk.FactSetPrices.Configuration(
    # ...
    ssl_ca_cert='/path/to/ca.pem'
)
```

### Request Retries

In case the request retry behaviour should be customized, it is possible to pass a `urllib3.Retry` object to the `retry` property of the Configuration.

```python
from urllib3 import Retry
import fds.sdk.FactSetPrices

configuration = fds.sdk.FactSetPrices.Configuration(
    # ...
)

configuration.retries = Retry(total=3, status_forcelist=[500, 502, 503, 504])
```


## Documentation for API Endpoints

All URIs are relative to *https://api.factset.com/content*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*BatchProcessingApi* | [**get_batch_data**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/BatchProcessingApi.md#get_batch_data) | **GET** /batch/v1/result | Returns the response for a Batch Request
*BatchProcessingApi* | [**get_batch_data_with_post**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/BatchProcessingApi.md#get_batch_data_with_post) | **POST** /batch/v1/result | Returns the response for a Batch Request
*BatchProcessingApi* | [**get_batch_status**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/BatchProcessingApi.md#get_batch_status) | **GET** /batch/v1/status | Returns the status for a Batch Request
*BatchProcessingApi* | [**get_batch_status_with_post**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/BatchProcessingApi.md#get_batch_status_with_post) | **POST** /batch/v1/status | Returns the status for a Batch Request
*DatabaseRolloverApi* | [**get_database_rollover**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/DatabaseRolloverApi.md#get_database_rollover) | **GET** /factset-prices/v1/database-rollover | Gets the latest relative rollover date for the database.
*DatabaseRolloverApi* | [**get_database_rollover_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/DatabaseRolloverApi.md#get_database_rollover_for_list) | **POST** /factset-prices/v1/database-rollover | Gets the latest relative rollover date for the database.
*DividendsApi* | [**get_security_dividends**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/DividendsApi.md#get_security_dividends) | **GET** /factset-prices/v1/dividends | Gets dividend information for a given date range and list of securities
*DividendsApi* | [**get_security_dividends_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/DividendsApi.md#get_security_dividends_for_list) | **POST** /factset-prices/v1/dividends | Requests dividend information for a given date range and list of securities
*HighLowApi* | [**get_high_low**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/HighLowApi.md#get_high_low) | **GET** /factset-prices/v1/high-low | Gets the price high and price low of securities for a list of &#x60;ids&#x60; as of given date, period and frequency.
*HighLowApi* | [**get_high_low_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/HighLowApi.md#get_high_low_for_list) | **POST** /factset-prices/v1/high-low | Requests the price high and price low of securities for a list of &#x60;ids&#x60; as of given date, period and frequency.
*MarketValueApi* | [**get_market_value**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/MarketValueApi.md#get_market_value) | **GET** /factset-prices/v1/market-value | Gets the security level and company level market values for a list of &#x60;ids&#x60; as of given date range and frequency.
*MarketValueApi* | [**get_market_value_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/MarketValueApi.md#get_market_value_for_list) | **POST** /factset-prices/v1/market-value | Requests the market value for a list of &#x60;ids&#x60; as of given date range.
*PricesApi* | [**get_fixed_security_prices**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/PricesApi.md#get_fixed_security_prices) | **GET** /factset-prices/v1/fixed-income | Gets pricing for a list of Fixed Income securities
*PricesApi* | [**get_fixed_security_prices_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/PricesApi.md#get_fixed_security_prices_for_list) | **POST** /factset-prices/v1/fixed-income | Requests pricing for a list of Fixed Income securities for date range requested
*PricesApi* | [**get_security_prices**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/PricesApi.md#get_security_prices) | **GET** /factset-prices/v1/prices | Gets end-of-day Open, High, Low, Close for a list of securities.
*PricesApi* | [**get_security_prices_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/PricesApi.md#get_security_prices_for_list) | **POST** /factset-prices/v1/prices | Requests end-of-day Open, High, Low, Close for a large list of securities.
*ReferenceApi* | [**get_security_reference_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/ReferenceApi.md#get_security_reference_for_list) | **POST** /factset-prices/v1/references | Requests security reference details a list of securities
*ReferenceApi* | [**get_security_references**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/ReferenceApi.md#get_security_references) | **GET** /factset-prices/v1/references | Gets security reference details for a list of securities
*ReturnsApi* | [**get_returns_snapshot**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/ReturnsApi.md#get_returns_snapshot) | **GET** /factset-prices/v1/returns-snapshot | Returns the price performance of the security and annualized compound total returns.
*ReturnsApi* | [**get_returns_snapshot_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/ReturnsApi.md#get_returns_snapshot_for_list) | **POST** /factset-prices/v1/returns-snapshot | Returns the price performance of the security and annualized compound total returns.
*ReturnsApi* | [**get_security_returns**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/ReturnsApi.md#get_security_returns) | **GET** /factset-prices/v1/returns | Gets Returns for a list of &#x60;ids&#x60; as of given date range and rolling Period
*ReturnsApi* | [**get_security_returns_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/ReturnsApi.md#get_security_returns_for_list) | **POST** /factset-prices/v1/returns | Requests security returns for the given date range and rollingPeriod.
*SharesApi* | [**get_security_shares**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/SharesApi.md#get_security_shares) | **GET** /factset-prices/v1/shares | Gets shares for a list of &#x60;ids&#x60; as of given date range.
*SharesApi* | [**get_security_shares_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/SharesApi.md#get_security_shares_for_list) | **POST** /factset-prices/v1/shares | Requests shares for a list of &#x60;ids&#x60; as of given date range.
*SplitsApi* | [**get_security_splits**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/SplitsApi.md#get_security_splits) | **GET** /factset-prices/v1/splits | Gets full history of security Splits for a list of &#x60;ids&#x60;
*SplitsApi* | [**get_security_splits_for_list**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/SplitsApi.md#get_security_splits_for_list) | **POST** /factset-prices/v1/splits | Requests splits for a list of &#x60;ids&#x60;


## Documentation For Models

 - [Adjust](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/Adjust.md)
 - [Batch](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/Batch.md)
 - [BatchDataRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/BatchDataRequest.md)
 - [BatchDataResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/BatchDataResponse.md)
 - [BatchStatus](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/BatchStatus.md)
 - [BatchStatusRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/BatchStatusRequest.md)
 - [BatchStatusResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/BatchStatusResponse.md)
 - [Calendar](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/Calendar.md)
 - [Dividend](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/Dividend.md)
 - [DividendAdjust](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/DividendAdjust.md)
 - [DividendAdjustSnapshot](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/DividendAdjustSnapshot.md)
 - [DividendsRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/DividendsRequest.md)
 - [DividendsResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/DividendsResponse.md)
 - [ErrorResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/ErrorResponse.md)
 - [ErrorResponseSubErrors](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/ErrorResponseSubErrors.md)
 - [FixedIds](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/FixedIds.md)
 - [FixedIncomePrice](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/FixedIncomePrice.md)
 - [Frequency](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/Frequency.md)
 - [FrequencyFi](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/FrequencyFi.md)
 - [HighLow](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/HighLow.md)
 - [HighLowRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/HighLowRequest.md)
 - [HighLowResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/HighLowResponse.md)
 - [IdsBatchMax5000](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/IdsBatchMax5000.md)
 - [IdsMax1000](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/IdsMax1000.md)
 - [IdsMax2000](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/IdsMax2000.md)
 - [MarketValue](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/MarketValue.md)
 - [MarketValueRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/MarketValueRequest.md)
 - [MarketValueResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/MarketValueResponse.md)
 - [ModelReturn](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/ModelReturn.md)
 - [Period](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/Period.md)
 - [Price](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/Price.md)
 - [PriceType](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/PriceType.md)
 - [PricesFixedIncomeRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/PricesFixedIncomeRequest.md)
 - [PricesFixedIncomeResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/PricesFixedIncomeResponse.md)
 - [PricesRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/PricesRequest.md)
 - [PricesResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/PricesResponse.md)
 - [References](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/References.md)
 - [ReferencesRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/ReferencesRequest.md)
 - [ReferencesResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/ReferencesResponse.md)
 - [ReturnsRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/ReturnsRequest.md)
 - [ReturnsResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/ReturnsResponse.md)
 - [ReturnsSnapshot](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/ReturnsSnapshot.md)
 - [ReturnsSnapshotRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/ReturnsSnapshotRequest.md)
 - [ReturnsSnapshotResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/ReturnsSnapshotResponse.md)
 - [RollingPeriod](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/RollingPeriod.md)
 - [Rollover](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/Rollover.md)
 - [RolloverResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/RolloverResponse.md)
 - [Shares](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/Shares.md)
 - [SharesRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/SharesRequest.md)
 - [SharesResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/SharesResponse.md)
 - [SplitAdjust](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/SplitAdjust.md)
 - [Splits](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/Splits.md)
 - [SplitsRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/SplitsRequest.md)
 - [SplitsResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/FactSetPrices/v1/docs/SplitsResponse.md)


## Documentation For Authorization


## FactSetApiKey

- **Type**: HTTP basic authentication


## FactSetOAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: N/A


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in fds.sdk.FactSetPrices.apis and fds.sdk.FactSetPrices.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from fds.sdk.FactSetPrices.api.default_api import DefaultApi`
- `from fds.sdk.FactSetPrices.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import fds.sdk.FactSetPrices
from fds.sdk.FactSetPrices.apis import *
from fds.sdk.FactSetPrices.models import *
```

## Contributing

Please refer to the [contributing guide](../../../../CONTRIBUTING.md).

## Copyright

Copyright 2022 FactSet Research Systems Inc

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

